/**************************************************************************
/* This class is part of the Java Plotlib Toolkit.
/*
/* Copyright (c) 1999-2004 by Bernhard Bablok (mail@bablokb.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/
package de.bablokb.plotlib.core;

/**
   A properties-object for axis properties.

   @version $Revision: 1.3 $
   @author  $Author: bablokb $
*/

public class AxisProperties extends BasicProperties {

  /////////////////////////////////////////////////////////////////////////////

  /**
     Symbol-type for head of axis. The value is one of the constants 
     defined in the Plotlib class.
  */

  private int iHeadSymbolType = Plotlib.NONE;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Symbol-size for head of axis. The value is one of the constants 
     defined in the Plotlib class.
  */

  private int iHeadSymbolSize = Plotlib.BIG;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Symbol-type for tail of axis. The value is one of the constants 
     defined in the Plotlib class.
  */

  private int iTailSymbolType = Plotlib.NONE;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Symbol-size for tail of axis. The value is one of the constants 
     defined in the Plotlib class.
  */

  private int iTailSymbolSize = Plotlib.BIG;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Default constructor.
  */

  public AxisProperties() {
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Constructor with base object.
  */

  public AxisProperties(BasicProperties base) {
    super(base);
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set head symbol-type.
  */

  public void setHeadSymbolType(int type) {
    iHeadSymbolType = type;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set tail symbol-type.
  */

  public void setTailSymbolType(int type) {
    iTailSymbolType = type;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get head symbol-type.
  */

  public int getHeadSymbolType() {
    return iHeadSymbolType;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get tail symbol-type.
  */

  public int getTailSymbolType() {
    return iTailSymbolType;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set head symbol-size.
  */

  public void setHeadSymbolSize(int size) {
    iHeadSymbolSize = size;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set tail symbol-size.
  */

  public void setTailSymbolSize(int size) {
    iTailSymbolSize = size;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get head symbol-size.
  */

  public int getHeadSymbolSize() {
    return iHeadSymbolSize;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get tail symbol-size.
  */

  public int getTailSymbolSize() {
    return iTailSymbolSize;
  }
}
