/**************************************************************************
/* This class is part of the Java Plotlib Toolkit.
/*
/* Copyright (c) 1999-2004 by Bernhard Bablok (bablokb@gmx.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/
package de.bablokb.plotlib.core;

import java.awt.*;

/**
   A properties-object for standard properites (color, width) and methods
   to handle these properties.

   @version $Revision: 1.2 $
   @author  $Author: bablokb $
*/

public class BasicProperties {

  /////////////////////////////////////////////////////////////////////////////

  /**
     Color of the object. If null, use the default color.
  */

  protected Color iColor = null;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Width (THIN, MEDIUM, WIDE or given width) of the object.
     Defaults to THIN.
  */

  protected int iWidth = Plotlib.THIN;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Dash type.
  */

  private int iDashType = Plotlib.SOLID;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Default constructor.
  */

  public BasicProperties() {
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Shallow copy constructor.
  */

  public BasicProperties(BasicProperties src) {
    iColor    = src.getColor();
    iWidth    = src.getWidth();
    iDashType = src.getDashType();
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set the color of the object.
  */

  public void setColor(Color c) {
    iColor = c;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set the width of the object.
  */

  public void setWidth(int w) {
    iWidth = w;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get the color of the object.
  */

  public Color getColor() {
    return iColor;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get the width of the object.
  */

  public int getWidth() {
    return iWidth;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set dash type of Line.
  */

  public void setDashType(int type) {
    iDashType = type;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get dash type of Line.
  */

  public int getDashType() {
    return iDashType;
  }
}
