/**************************************************************************
/* This class is part of the Java Plotlib Toolkit.
/*
/* Copyright (c) 1999-2004 by Bernhard Bablok (bablokb@gmx.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/
package de.bablokb.plotlib.core;

import java.util.*;
import java.awt.*;
import java.awt.geom.*;

/**
   Plot a border defined by a rectangle. If the rectangle is not set, it
   defaults to the range of the PlottingContext.

   @version $Revision: 1.2 $
   @author  $Author: bablokb $
*/

public class Border  extends AbstractPlottable {

  /**
     The border rectangle. This defaults to
     the range of the PlottingContext.
  */

  private Rectangle2D iBorder = null;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Create a Border with default range.
  */

  public Border() {
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Create a Border with given rectangle. 
  */

  public Border(Rectangle2D border) {
    iBorder = border;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set the border.
  */

  public void setBorder(Rectangle2D border) {
    iBorder = border;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Query the border.
  */

  public Rectangle2D getBorder() {
    return iBorder;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Plot the border. Implements AbstractPlottable.plotObjects.
  */

  public void plotObjects(PlottingContext pc) {
    Graphics2D g2 = pc.getG2();
    Rectangle2D b;
    if (iBorder == null)
      b = pc.getRange();
    else
      b = iBorder;
    g2.draw(pc.transform(b));
  }
}

