/**************************************************************************
/* This class is part of the Java Plotlib Toolkit.
/*
/* Copyright (c) 1999-2004 by Bernhard Bablok (mail@bablokb.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/
package de.bablokb.plotlib.core;

import java.util.*;
import java.awt.*;
import java.awt.geom.*;

/**
   An abstract class with basic behaviour for composite plottable objects.
   The difference to AbstractPlottable is that CompositePlottable has no
   properties object, therefore does not have to save state before plotting
   and have to restore state afterwards.

   @see de.bablokb.plotlib.core.AbstractPlottable

   @version $Revision: 1.2 $
   @author  $Author: bablokb $
*/

public abstract class CompositePlottable implements Plottable {

  /////////////////////////////////////////////////////////////////////////////

  /**
     Implement Plottable.plot(). This is just a wrapper for plotObjects(),
     which must be overridden by sublcasses.
  */

  public void plot(PlottingContext pc) {
    plotObjects(pc);
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Plot current object. Must be overridden by subclasses.
  */

  public abstract void plotObjects(PlottingContext pc);
}
