/**************************************************************************
/* This class is part of the Java Plotlib Toolkit.
/*
/* Copyright (c) 1999-2004 by Bernhard Bablok (bablokb@gmx.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/
package de.bablokb.plotlib.core;

import java.awt.geom.*;

/**
   This class is the default Toolkit. All factory methods for Java2D classes
   return the float versions (e.g. Line2D.float). This class can't be
   instantiated directly. You should use Toolkit.getDefaultToolkit() to
   instantiate the class.
  
   @version $Revision: 1.2 $
   @author  $Author: bablokb $
*/

public class FloatToolkit extends Toolkit {

  /**
     Protected constructor. Should only be instantiated by plotlib classes.
  */

  protected FloatToolkit() {
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Returns a Point2D.Float.
  */

  public Point2D getPoint2D() {
    return new Point2D.Float();
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Returns a Point2D-Array of given size.
  */

  public Point2D[] getPoint2DArray(int size) {
    Point2D[] result = new Point2D[size];
    for (int i=0;i<size;++i)
      result[i] = new Point2D.Float();
    return result;
  }

  /**
     Returns a Rectangle2D.Float.
  */

  public Rectangle2D getRectangle2D() {
    return new Rectangle2D.Float();
  }

  /**
     Returns a Line2D.Float.
  */

  public Line2D getLine2D() {
    return new Line2D.Float();
  }

  /**
     Returns a Arc2D.Float.
  */

  public Arc2D getArc2D() {
    return new Arc2D.Float();
  }
}
