/**************************************************************************
/* This class is part of the Java Plotlib Toolkit.
/*
/* Copyright (c) 1999-2004 by Bernhard Bablok (mail@bablokb.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/
package de.bablokb.plotlib.core;

/**
   A properties-object for PLabel properties and methods
   to handle these properties.

   @version $Revision: 1.3 $
   @author  $Author: bablokb $
*/

public class PLabelProperties extends BasicProperties {

  /////////////////////////////////////////////////////////////////////////////

  /**
     Space, Glue (NOT IMPLEMENTED)

  */

  private int iSpace = 0;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Position of the text relative to the reference point. Value should be
     one of the predefined constants.  (NOT IMPLEMENTED)
  */

  private int iAnchor = Plotlib.NORTH;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Direction. <strong>FIXME: use a constant or an angle??</strong>.
      (NOT IMPLEMENTED)
  */

  private int iDir;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Rotation angle of characters in text.  (NOT IMPLEMENTED)
  */

  private float iAngle;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Default constructor.
  */

  public PLabelProperties() {
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Constructor with base object.
  */

  public PLabelProperties(BasicProperties base) {
    super(base);
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set space.
  */

  public void setSpace(int space) {
    iSpace = space;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set anchor of text relative to the reference point.
  */

  public void setAnchor(int anchor) {
    iAnchor = anchor;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set direction of the text.
  */

  public void setDir(int dir) {
    iDir = dir;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set angle.
  */

  public void setAngle(float angle) {
    iAngle = angle;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get space.
  */

  public int getSpace() {
    return iSpace;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get anchor of text relative to the reference point.
  */

  public int getAnchor() {
    return iAnchor;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get direction of the text.
  */

  public int getDir() {
    return iDir;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get angle.
  */

  public float getAngle() {
    return iAngle;
  }
}
