/**************************************************************************
/* This class is part of the Java Plotlib Toolkit.
/*
/* Copyright (c) 1999-2004 by Bernhard Bablok (bablokb@gmx.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/
package de.bablokb.plotlib.core;

import java.util.*;

/**
   A hashtable implementing the Plottable interface.

   @see de.bablokb.plotlib.core.Plottable

   @version $Revision: 1.2 $
   @author  $Author: bablokb $
*/

public class PlotHashtable extends Hashtable implements Plottable {

  /////////////////////////////////////////////////////////////////////////////

  /**
     Default constructor.
  */

  public PlotHashtable() {
    super();
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Constructor with initial capacity.
  */

  public PlotHashtable(int initialCapacity) {
    super(initialCapacity);
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Constructor with initial capacity and load factor.
  */

  public PlotHashtable(int initialCapacity, float loadFactor) {
    super(initialCapacity,loadFactor);
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Call plot() method of all elements in the hashtable. Implements 
     Plottable.plot()
  */

  public void plot(PlottingContext context) {
    Enumeration e = elements();
    while (e.hasMoreElements()) {
      Plottable p = (Plottable) e.nextElement();
      p.plot(context);
    }
  }
}
