/**************************************************************************
/* This class is part of the Java Plotlib Toolkit.
/*
/* Copyright (c) 1999-2004 by Bernhard Bablok (bablokb@gmx.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/
package de.bablokb.plotlib.core;

import java.util.*;

/**
   An ArrayList implementing the Plottable interface.

   @see de.bablokb.plotlib.core.Plottable

   @version $Revision: 1.2 $
   @author  $Author: bablokb $
*/

public class PlotList extends ArrayList implements Plottable {

  /////////////////////////////////////////////////////////////////////////////

  /**
     Default constructor.
  */

  public PlotList() {
    super();
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Constructor with initial capacity.
  */

  public PlotList(int initialCapacity) {
    super(initialCapacity);
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Constructors a list containing the elements of the given collection,
     in the order they are returned by the collection's iterator.
  */

  public PlotList(Collection c) {
    super(c);
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set properties object on all elements. Note that this will result in
     a runtime-error, if not all elements are of the same type.
  */

  public void setProperties(BasicProperties prop) {
    ListIterator lit = listIterator();
    while (lit.hasNext()) {
      AbstractPlottable ap = (AbstractPlottable) lit.next();
      ap.setProperties(prop);
    }
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Call plot() method of all elements in the list. Implements 
     Plottable.plot()
  */

  public void plot(PlottingContext context) {
    ListIterator lit = listIterator();
    while (lit.hasNext()) {
      Plottable p = (Plottable) lit.next();
      p.plot(context);
    }
  }
}
