/**************************************************************************
/* This class is part of the Java Plotlib Toolkit.
/*
/* Copyright (c) 1999-2004 by Bernhard Bablok (mail@bablokb.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/
package de.bablokb.plotlib.core;

/**
   Global constants of the Java Plotlib Toolkit.

   @version $Revision: 1.3 $
   @author  $Author: bablokb $
*/

public final class Plotlib {

  /////////////////////////////////////////////////////////////////////////////

  /**
     Predefined size constant.
  */

  public final static int
    SMALL =  3,
    BIG   =  6,
    LARGE = 12;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Predefined width constant.
  */

  public final static int
    THIN   = 1,
    MEDIUM = 2,
    WIDE   = 4;
  
  /////////////////////////////////////////////////////////////////////////////

  /**
     Predefined length constant.
  */

  public final static float
    DOT_LENGTH = 1.0f,
    DASH_LENGTH = 8.0f;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Predefined dash type constant.
  */

  public final static int
    SOLID      = -1,
    DOT        = 0,
    DASH       = 1,
    DASHDOT    = 2,
    DASHDOTDOT = 3;  
  
  /////////////////////////////////////////////////////////////////////////////

  /**
     Mapping of type to dash-array. To add new dash types, add a new
     dash-array to iDashTable and a type constant.
     You have to insure that the index of the entry matches the
     type constant.
  */

  public static final float[][] DASH_TABLE = {
    new float[] {DOT_LENGTH},
    new float[] {DASH_LENGTH,DOT_LENGTH},
    new float[] {DASH_LENGTH,DOT_LENGTH,DOT_LENGTH,DOT_LENGTH},
    new float[] {DASH_LENGTH,DOT_LENGTH,
			    DOT_LENGTH,DOT_LENGTH,DOT_LENGTH,DOT_LENGTH}
  };

  /////////////////////////////////////////////////////////////////////////////

  /**
     Predefined symbol type constant.
  */

  public final static int
    NONE   = -1,
    CIRCLE = 0,
    MINUS  = 1,
    PLUS   = 2,
    STAR   = 3,
    SQUARE = 4,
    VERT   = 5,
    NARROW = 6,
    EARROW = 7,
    SARROW = 8,
    WARROW = 9;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Mapping of type to Form-object. To add new symbols, subclass Form, add
     a new type constant and create an object of the new subclass in the
     array. You have to insure that the index of the object matches the
     type constant.

     @see de.bablokb.plotlib.core.Form
  */

  public static final Form[] FORM_TABLE = {
    new Form.Circle(),
    new Form.Minus(),
    new Form.Plus(),
    new Form.Star(),
    new Form.Square(),
    new Form.Vert(),
    new Form.NArrow(),
    new Form.EArrow(),
    new Form.SArrow(),
    new Form.WArrow()
  };

  /////////////////////////////////////////////////////////////////////////////

  /**
     Predefined orientation constant.
  */

  public final static int
    UNDEFINED  = -1,
    VERTICAL   = 0,
    HORIZONTAL = 1;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Predefined tickmark constant.
  */

  public final static int
    MAJOR = 0,
    MINOR = 1;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Predefined anchor constant.
  */

  public final static int
    NORTH     = 0,
    NORTHEAST = 1,
    EAST      = 2,
    SOUTHEAST = 3,
    SOUTH     = 4,
    SOUTHWEST = 5,
    WEST      = 6,
    NORTHWEST = 7;
}
