/**************************************************************************
/* This class is part of the Java Plotlib Toolkit.
/*
/* Copyright (c) 1999-2004 by Bernhard Bablok (bablokb@gmx.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Library General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/
package de.bablokb.plotlib.core;

import java.util.*;
import java.awt.geom.*;

/**
   A properties-object for TickMarks objects.
  
   @version $Revision: 1.3 $
   @author  $Author: bablokb $
*/

public class TickMarkProperties extends BasicProperties {

  /////////////////////////////////////////////////////////////////////////////

  /**
     Type of tickmark. One of the predefined constants in Plotlib.
  */

  private int iTickMarksType = Plotlib.UNDEFINED;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Size of the tickmark-symbols. The size is interpreted in
     device units.
  */

  private int iSize = Plotlib.SMALL;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Orientation of the tickmarks.
  */

  private int iOrientation = Plotlib.HORIZONTAL;

  /////////////////////////////////////////////////////////////////////////////

  /**
     Default constructor.
  */

  public TickMarkProperties() {
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Constructor with base object.
  */

  public TickMarkProperties(BasicProperties base) {
    super(base);
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set the tickmarks-type.
  */

  public void setTickMarksType(int type) {
    iTickMarksType = type;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set size of Symbols.
  */

  public void setSize(int size) {
    iSize = size;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Set the orientation of the lines.
  */

  public void setOrientation(int o) {
    iOrientation = o;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get the tickmarks-type.
  */

  public int getTickMarksType() {
    return iTickMarksType;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Get size of tickmarks.
  */

  public int getSize() {
    return iSize;
  }

  /////////////////////////////////////////////////////////////////////////////

  /**
     Query the orientation of the tickmarks.
  */

  public int getOrientation() {
    return iOrientation;
  }
}
